summaryrefslogtreecommitdiff
path: root/vendor/symfony/http-kernel/Exception/MethodNotAllowedHttpException.php
diff options
context:
space:
mode:
Diffstat (limited to 'vendor/symfony/http-kernel/Exception/MethodNotAllowedHttpException.php')
-rw-r--r--vendor/symfony/http-kernel/Exception/MethodNotAllowedHttpException.php4
1 files changed, 2 insertions, 2 deletions
diff --git a/vendor/symfony/http-kernel/Exception/MethodNotAllowedHttpException.php b/vendor/symfony/http-kernel/Exception/MethodNotAllowedHttpException.php
index e9a3f069f1..388c8c704e 100644
--- a/vendor/symfony/http-kernel/Exception/MethodNotAllowedHttpException.php
+++ b/vendor/symfony/http-kernel/Exception/MethodNotAllowedHttpException.php
@@ -19,11 +19,11 @@ class MethodNotAllowedHttpException extends HttpException
/**
* @param array $allow An array of allowed methods
* @param string $message The internal exception message
* @param \Exception $previous The previous exception
* @param int $code The internal exception code
* @param array $headers
*/
- public function __construct(array $allow, string $message = null, \Exception $previous = null, ?int $code = 0, array $headers = [])
+ public function __construct(array $allow, string $message = null, \Throwable $previous = null, ?int $code = 0, array $headers = [])
{
$headers['Allow'] = strtoupper(implode(', ', $allow));
@@ -19,11 +19,11 @@ class MethodNotAllowedHttpException extends HttpException
* @param array $allow An array of allowed methods
* @param string $message The internal exception message
- * @param \Exception $previous The previous exception
+ * @param \Throwable $previous The previous exception
* @param int $code The internal exception code
* @param array $headers